==> ejc-zdsmaterialb-api-3.0.0-20241015.015712-31-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 物资总控计划
 * 
 * @author generator
 * 
 */
public class ControlPlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String billName; // 单据名称
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 上级组织id
    private String parentOrgCode; // 上级组织编码
    private String parentOrgName; // 上级组织名称
    private Long engineerId; // 主责工程师
    private String engineerName; // 主责工程师名称
    private Long managerId; // 项目总工
    private String managerName; // 项目总工名称
    private String memo; // 备注
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName;// 编制者名称
    private Long projectManagerId; // 项目经理主键
    private String projectManagerName; // 项目经理名称
    private String billStateName; // 单据状态名称
    private Integer billType; // 单据类型：1-编制，2-变更
    private Long changeTypeId; // 变更原因类型主键
    private Integer changeVersion; // 变更版本
    private String materialTypeNames; // 材料分类
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private Long createUserId;// 制单人Id

    private List<ControlPlanDetailVO> detailList = new ArrayList<>(); // 物资总控计划明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEngineerId() {
        return engineerId;
    }

    @ReferDeserialTransfer
    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }

    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getManagerId() {
        return managerId;
    }

    @ReferDeserialTransfer
    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getProjectManagerId() {
        return projectManagerId;
    }
    @ReferDeserialTransfer
    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getChangeTypeId() {
        return changeTypeId;
    }

    @ReferDeserialTransfer
    public void setChangeTypeId(Long changeTypeId) {
        this.changeTypeId = changeTypeId;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getMaterialTypeNames() {
        return materialTypeNames;
    }

    public void setMaterialTypeNames(String materialTypeNames) {
        this.materialTypeNames = materialTypeNames;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public List<ControlPlanDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<ControlPlanDetailVO> detailList) {
        this.detailList = detailList;
     }
}

==> ejc-zdsmaterialb-api-3.0.0-20251031.013959-69-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import com.ejianc.business.zdsmaterial.plan.conjecture.vo.MaterialConjectureVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 物资总控计划
 *
 * @author generator
 *
 */
public class ControlPlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编号
    private String billName; // 单据名称
    private Long projectId; // 项目
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 组织
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 上级组织id
    private String parentOrgCode; // 上级组织编码
    private String parentOrgName; // 上级组织名称
    private Long engineerId; // 主责工程师
    private String engineerName; // 主责工程师名称
    private Long managerId; // 项目总工
    private String managerName; // 项目总工名称
    private String memo; // 备注
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName;// 编制者名称
    private Long projectManagerId; // 项目经理主键
    private String projectManagerName; // 项目经理名称
    private String billStateName; // 单据状态名称
    private Integer billType; // 单据类型：1-编制，2-变更
    private Long changeTypeId; // 变更原因类型主键
    private Integer changeVersion; // 变更版本
    private String materialTypeNames; // 材料分类
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    private Long createUserId;// 制单人Id

    private Long exeOrgId; // 执行总部id
    private String exeOrgCode; // 执行总部编码
    private String exeOrgName; // 执行总部名称

    private String curIdentifyId; //当前物料识别标识

    private String budgetVer; // 管控方式
    private String packId; // 费用包id
    private String packCode; // 费用包code
    private String packName; // 费用包name
    private String materialPackIds; // 物资分类ids

    public String getMaterialPackIds() {
        return materialPackIds;
    }

    public void setMaterialPackIds(String materialPackIds) {
        this.materialPackIds = materialPackIds;
    }
    @ReferSerialTransfer(referCode="cost-budget")
    public String getPackId() {
        return packId;
    }
    @ReferDeserialTransfer
    public void setPackId(String packId) {
        this.packId = packId;
    }

    public String getPackCode() {
        return packCode;
    }

    public void setPackCode(String packCode) {
        this.packCode = packCode;
    }

    public String getPackName() {
        return packName;
    }

    public void setPackName(String packName) {
        this.packName = packName;
    }

    public String getBudgetVer() {
        return budgetVer;
    }

    public void setBudgetVer(String budgetVer) {
        this.budgetVer = budgetVer;
    }

    public String getCurIdentifyId() {
        return curIdentifyId;
    }

    public void setCurIdentifyId(String curIdentifyId) {
        this.curIdentifyId = curIdentifyId;
    }

    private List<MaterialConjectureVO> identifyList; //待识别物料里列表

    public List<MaterialConjectureVO> getIdentifyList() {
        return identifyList;
    }

    public void setIdentifyList(List<MaterialConjectureVO> identifyList) {
        this.identifyList = identifyList;
    }


    private List<ControlPlanDetailVO> detailList = new ArrayList<>(); // 物资总控计划明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }

    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEngineerId() {
        return engineerId;
    }

    @ReferDeserialTransfer
    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }

    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getManagerId() {
        return managerId;
    }

    @ReferDeserialTransfer
    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }

    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getProjectManagerId() {
        return projectManagerId;
    }
    @ReferDeserialTransfer
    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getChangeTypeId() {
        return changeTypeId;
    }

    @ReferDeserialTransfer
    public void setChangeTypeId(Long changeTypeId) {
        this.changeTypeId = changeTypeId;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getMaterialTypeNames() {
        return materialTypeNames;
    }

    public void setMaterialTypeNames(String materialTypeNames) {
        this.materialTypeNames = materialTypeNames;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public Long getExeOrgId() {
        return exeOrgId;
    }

    public void setExeOrgId(Long exeOrgId) {
        this.exeOrgId = exeOrgId;
    }

    public String getExeOrgCode() {
        return exeOrgCode;
    }

    public void setExeOrgCode(String exeOrgCode) {
        this.exeOrgCode = exeOrgCode;
    }

    public String getExeOrgName() {
        return exeOrgName;
    }

    public void setExeOrgName(String exeOrgName) {
        this.exeOrgName = exeOrgName;
    }

    public List<ControlPlanDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<ControlPlanDetailVO> detailList) {
        this.detailList = detailList;
     }
}
